==> TOSTER_0.4.2.tar.gz: TOSTER/tests/testthat/test-bootTOST.R <==
#context("Run Examples for boot_t_TOST")

# need hush function to run print through examples

hush = function(code) {
  sink("NUL") # use /dev/null in UNIX
  tmp = code
  sink()
  return(tmp)
}

test_that("Run examples for one sample", {

  set.seed(31653464)

  samp1 = rnorm(33)

  expect_error(boot_t_TOST())

  # Normal one sample ----

  test1 = boot_t_TOST(x = samp1,
                 low_eqbound = -.5,
                 high_eqbound = .5,
                 R = 99)

  test3 = boot_t_TOST(x = samp1,
                 low_eqbound = -.5,
                 high_eqbound = .5,
                 hypothesis = "MET",
                 R = 99)

  expect_equal(1-test1$TOST$p.value[2],
               test3$TOST$p.value[2],
               tolerance = .1)

  expect_equal(1-test1$TOST$p.value[3],
               test3$TOST$p.value[3],
               tolerance = .1)

  expect_equal(test1$effsize$estimate,
               test3$effsize$estimate,
               ignore_attr = TRUE)

  expect_equal(1-test1$TOST$p.value[3],
               test3$TOST$p.value[3],
               tolerance = .1)

  # Re-run with bias correction not run -----
  test1 = boot_t_TOST(x = samp1,
                 low_eqbound = -.5,
                 high_eqbound = .5,
                 bias_correction = FALSE,
                 R = 99)

  test3 = boot_t_TOST(x = samp1,
                 low_eqbound = -.5,
                 high_eqbound = .5,
                 hypothesis = "MET",
                 bias_correction = FALSE,
                 R = 99)


  expect_equal(1-test1$TOST$p.value[3],
               test3$TOST$p.value[3],
               tolerance = .1)

  expect_equal(test1$effsize$estimate,
               test3$effsize$estimate,
               ignore_attr = TRUE)

  expect_equal(1-test1$TOST$p.value[3],
               test3$TOST$p.value[3],
               tolerance = .1)


  prtest = hush(print(test1))
  p1 = plot(test1)
  p2 = expect_warning(plot(test1,
            type = "c"))

})


test_that("Run examples for two sample", {

  set.seed(76584441)

  samp1 = rnorm(25)
  samp2 = rnorm(25)

  df_samp = data.frame(y = c(samp1,samp2),
                       group = c(rep("g1",25),
                                 rep("g2",25)))

  expect_error(boot_t_TOST())

  test1 = boot_t_TOST(x = samp1,
                 y = samp2,
                 low_eqbound = -.5,
                 high_eqbound = .5,
                 R = 199)

  test3 = boot_t_TOST(x = samp1,
                 y = samp2,
                 low_eqbound = -.5,
                 high_eqbound = .5,
                 hypothesis = "MET",
                 R = 199)

  expect_equal(1-test1$TOST$p.value[2],
               test3$TOST$p.value[2],
               tolerance = .1)

  expect_equal(1-test1$TOST$p.value[3],
               test3$TOST$p.value[3],
               tolerance = .1)

  expect_equal(test1$effsize$estimate,
               test3$effsize$estimate,
               ignore_attr = TRUE)

  expect_equal(1-test1$TOST$p.value[3],
               test3$TOST$p.value[3],
               tolerance = .1)



  # Re-run with bias correction not run and non-Welch ----
  test1 = boot_t_TOST(x = samp1,
                 y = samp2,
                 var.equal = TRUE,
                 low_eqbound = -.5,
                 high_eqbound = .5,
                 bias_correction = FALSE,
                 R = 199)

  test3 = boot_t_TOST(x = samp1,
                 y = samp2,
                 var.equal = TRUE,
                 low_eqbound = -.5,
                 high_eqbound = .5,
                 hypothesis = "MET",
                 bias_correction = FALSE,
                 R = 199)


  expect_equal(1-test1$TOST$p.value[2],
               test3$TOST$p.value[2],
               tolerance = .1)

  expect_equal(1-test1$TOST$p.value[3],
               test3$TOST$p.value[3],
               tolerance = .1)

  expect_equal(test1$effsize$estimate,
               test3$effsize$estimate,
               ignore_attr = TRUE)

  expect_equal(1-test1$TOST$p.value[3],
               test3$TOST$p.value[3],
               tolerance = .1)

})


test_that("Run examples for paired samples", {

  set.seed(921387)

  samp1 = rnorm(25)
  samp2 = rnorm(25)

  cor12 = stats::cor(samp1,samp2)

  df_samp = data.frame(y = c(samp1,samp2),
                       group = c(rep("g1",25),
                                 rep("g2",25)))

  expect_error(boot_t_TOST())

  test1 = boot_t_TOST(x = samp1,
                 y = samp2,
                 paired = TRUE,
                 low_eqbound = -.5,
                 high_eqbound = .5,
                 R = 199)

  test3 = boot_t_TOST(x = samp1,
                 y = samp2,
                 paired = TRUE,
                 low_eqbound = -.5,
                 high_eqbound = .5,
                 hypothesis = "MET",
                 R = 199)

  expect_equal(1-test1$TOST$p.value[2],
               test3$TOST$p.value[2],
               tolerance = .1)

  expect_equal(1-test1$TOST$p.value[3],
               test3$TOST$p.value[3],
               tolerance = .1)

  expect_equal(test1$effsize$estimate,
               test3$effsize$estimate,
               ignore_attr = TRUE)

  expect_equal(1-test1$TOST$p.value[3],
               test3$TOST$p.value[3],
               tolerance = .1)

})

==> TOSTER_0.6.0.tar.gz: TOSTER/tests/testthat/test-bootTOST.R <==
#context("Run Examples for boot_t_TOST")

# need hush function to run print through examples

hush = function(code) {
  sink("NUL") # use /dev/null in UNIX
  tmp = code
  sink()
  return(tmp)
}

test_that("Run examples for one sample", {

  set.seed(31653464)

  samp1 = rnorm(33)

  expect_error(boot_t_TOST())
  expect_error(boot_t_TOST(x = samp1,
                           eqb = "test",
                           R = 99))
  expect_error(boot_t_TOST(x = samp1,
                           low_eqbound = -.5,
                           high_eqbound = .5,
                           alpha = 1.22,
                           R = 99))
  expect_error(boot_t_TOST(Sepal.Width ~ Species, data = iris))

  # Normal one sample ----

  test1 = boot_t_TOST(x = samp1,
                 low_eqbound = -.5,
                 high_eqbound = .5,
                 R = 99)
  test1 = boot_t_TOST(x = samp1,
                      eqb = .5,
                      R = 99)

  expect_error( boot_log_TOST(x = samp1,
                      eqb = .5,
                      R = 99))

  test3 = boot_t_TOST(x = samp1,
                 low_eqbound = -.5,
                 high_eqbound = .5,
                 hypothesis = "MET",
                 R = 99)

  expect_equal(1-test1$TOST$p.value[2],
               test3$TOST$p.value[2],
               tolerance = .1)

  expect_equal(1-test1$TOST$p.value[3],
               test3$TOST$p.value[3],
               tolerance = .1)

  expect_equal(test1$effsize$estimate,
               test3$effsize$estimate,
               ignore_attr = TRUE)

  expect_equal(1-test1$TOST$p.value[3],
               test3$TOST$p.value[3],
               tolerance = .1)

  # Re-run with bias correction not run -----
  test1 = boot_t_TOST(x = samp1,
                 low_eqbound = -.5,
                 high_eqbound = .5,
                 bias_correction = FALSE,
                 R = 99)

  test3 = boot_t_TOST(x = samp1,
                 low_eqbound = -.5,
                 high_eqbound = .5,
                 hypothesis = "MET",
                 bias_correction = FALSE,
                 R = 99)


  expect_equal(1-test1$TOST$p.value[3],
               test3$TOST$p.value[3],
               tolerance = .1)

  expect_equal(test1$effsize$estimate,
               test3$effsize$estimate,
               ignore_attr = TRUE)

  expect_equal(1-test1$TOST$p.value[3],
               test3$TOST$p.value[3],
               tolerance = .1)


  prtest = hush(print(test1))
  p1 = plot(test1)
  p2 = expect_warning(plot(test1,
            type = "c"))

})


test_that("Run examples for two sample", {

  set.seed(76584441)

  samp1 = rnorm(25)
  samp2 = rnorm(25)

  df_samp = data.frame(y = c(samp1,samp2),
                       group = c(rep("g1",25),
                                 rep("g2",25)))

  expect_error(boot_t_TOST())

  test1 = boot_t_TOST(x = samp1,
                 y = samp2,
                 low_eqbound = -.5,
                 high_eqbound = .5,
                 R = 199)

  test3 = boot_t_TOST(x = samp1,
                 y = samp2,
                 low_eqbound = -.5,
                 high_eqbound = .5,
                 hypothesis = "MET",
                 R = 199)

  expect_equal(1-test1$TOST$p.value[2],
               test3$TOST$p.value[2],
               tolerance = .1)

  expect_equal(1-test1$TOST$p.value[3],
               test3$TOST$p.value[3],
               tolerance = .1)

  expect_equal(test1$effsize$estimate,
               test3$effsize$estimate,
               ignore_attr = TRUE)

  expect_equal(1-test1$TOST$p.value[3],
               test3$TOST$p.value[3],
               tolerance = .1)



  # Re-run with bias correction not run and non-Welch ----
  test1 = boot_t_TOST(x = samp1,
                 y = samp2,
                 var.equal = TRUE,
                 low_eqbound = -.5,
                 high_eqbound = .5,
                 bias_correction = FALSE,
                 R = 199)

  test1 = boot_t_TOST(x = samp1,
                      y = samp2,
                      var.equal = TRUE,
                      eqb = .5,
                      bias_correction = FALSE,
                      R = 199)


  test3 = boot_t_TOST(x = samp1,
                 y = samp2,
                 var.equal = TRUE,
                 low_eqbound = -.5,
                 high_eqbound = .5,
                 hypothesis = "MET",
                 bias_correction = FALSE,
                 R = 199)


  expect_equal(1-test1$TOST$p.value[2],
               test3$TOST$p.value[2],
               tolerance = .1)

  expect_equal(1-test1$TOST$p.value[3],
               test3$TOST$p.value[3],
               tolerance = .1)

  expect_equal(test1$effsize$estimate,
               test3$effsize$estimate,
               ignore_attr = TRUE)

  expect_equal(1-test1$TOST$p.value[3],
               test3$TOST$p.value[3],
               tolerance = .1)

})


test_that("Run examples for paired samples", {

  set.seed(921387)

  samp1 = rnorm(25)
  samp2 = rnorm(25)

  cor12 = stats::cor(samp1,samp2)

  df_samp = data.frame(y = c(samp1,samp2),
                       group = c(rep("g1",25),
                                 rep("g2",25)))

  expect_error(boot_t_TOST())

  test1 = boot_t_TOST(x = samp1,
                 y = samp2,
                 paired = TRUE,
                 low_eqbound = -.5,
                 high_eqbound = .5,
                 R = 199)

  test3 = boot_t_TOST(x = samp1,
                 y = samp2,
                 paired = TRUE,
                 low_eqbound = -.5,
                 high_eqbound = .5,
                 hypothesis = "MET",
                 R = 199)

  expect_equal(1-test1$TOST$p.value[2],
               test3$TOST$p.value[2],
               tolerance = .1)

  expect_equal(1-test1$TOST$p.value[3],
               test3$TOST$p.value[3],
               tolerance = .1)

  expect_equal(test1$effsize$estimate,
               test3$effsize$estimate,
               ignore_attr = TRUE)

  expect_equal(1-test1$TOST$p.value[3],
               test3$TOST$p.value[3],
               tolerance = .1)

})
